@@ -6,7 +6,7 @@
 #
 # This script requires autoconf-2.64..2.72 and automake-1.13..1.17 in the PATH.
 
-# Copyright (C) 2003-2024 Free Software Foundation, Inc.
+# Copyright (C) 2003-2025 Free Software Foundation, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -98,6 +98,7 @@ if ! $skip_gnulib; then
     attribute
     basename-lgpl
     binary-io
+    bool
     closeout
     error
     getopt-gnu
@@ -110,11 +111,10 @@ if ! $skip_gnulib; then
     relocatable-prog
     setlocale
     sigpipe
-    stdbool
-    stdio
-    stdlib
+    stdio-h
+    stdlib-h
     strtoul
-    unistd
+    unistd-h
     unlocked-io
     xalloc
     xstring-buffer
@@ -123,9 +123,13 @@ if ! $skip_gnulib; then
     gettext-runtime-misc
     ansi-c++-opt
     csharpcomp-script
+    d
+    dcomp-script
     java
     javacomp-script
     manywarnings
+    modula2
+    modula2comp-script
   '
   $GNULIB_TOOL --dir=gettext-runtime --lib=libgrt --source-base=gnulib-lib --m4-base=gnulib-m4 --no-libtool --local-dir=gnulib-local --local-symlink \
     --import $GNULIB_MODULES_RUNTIME_FOR_SRC $GNULIB_MODULES_RUNTIME_OTHER || exit $?
@@ -172,11 +176,13 @@ if ! $skip_gnulib; then
     binary-io
     bison
     bison-i18n
+    bool
     byteswap
     c-ctype
     c-strcase
     c-strcasestr
     c-strstr
+    carray-list
     clean-temp
     closedir
     closeout
@@ -200,14 +206,19 @@ if ! $skip_gnulib; then
     getaddrinfo
     getline
     getopt-gnu
+    getrusage
     gettext-h
+    gocomp-script
+    hash-map
+    hash-set
+    hashkey-string
     iconv
     javacomp
     javaexec
     libunistring-optional
     libxml
     localcharset
-    locale
+    locale-h
     localename
     localtime
     lock
@@ -217,6 +228,7 @@ if ! $skip_gnulib; then
     memset
     minmax
     mkdir
+    next-prime
     noreturn
     obstack
     open
@@ -229,6 +241,7 @@ if ! $skip_gnulib; then
     readdir
     relocatable-prog
     relocatable-script
+    set
     setlocale
     sf-istream
     sh-filename
@@ -236,61 +249,76 @@ if ! $skip_gnulib; then
     sigpipe
     sigprocmask
     spawn-pipe
-    stdbool
-    stdio
-    stdlib
+    stat-time
+    stdio-h
+    stdlib-h
     stpcpy
     stpncpy
+    str_startswith
     strchrnul
     strcspn
     strerror
     string-desc
+    strnlen
     strpbrk
     strtol
     strtoul
     supersede
-    sys_select
-    sys_stat
-    sys_time
+    sys_select-h
+    sys_stat-h
+    sys_time-h
     trim
     unicase/u8-casefold
     unictype/ctype-space
+    unictype/property-white-space
     unictype/syntax-java-whitespace
+    unictype/property-xid-start
+    unictype/property-xid-continue
     unilbrk/ulc-width-linebreaks
     uniname/uniname
     uninorm/nfc
-    unistd
+    unistd-h
     unistr/u8-check
     unistr/u8-mbtouc
     unistr/u8-mbtoucr
     unistr/u8-uctomb
+    unistr/u16-check
+    unistr/u16-to-u8
     unistr/u16-mbtouc
+    unistr/u32-check
+    unistr/u32-to-u8
     uniwidth/width
     unlocked-io
     unsetenv
     vasprintf
+    vc-mtime
     wait-process
     write
     xalloc
     xconcat-filename
     xerror
+    xlist
     xmalloca
+    xmap
     xmemdup0
+    xset
     xsetenv
     xstrerror
     xstriconv
     xstriconveh
     xstring-buffer
+    xstring-buffer-reversed
     xstring-desc
     xvasprintf
   '
   # Common dependencies of GNULIB_MODULES_TOOLS_FOR_SRC and GNULIB_MODULES_TOOLS_FOR_LIBGREP.
   GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES='
     alloca-opt
+    bool
     extensions
     gettext-h
     include_next
-    locale
+    locale-h
     localcharset
     malloc-posix
     mbrtowc
@@ -301,14 +329,13 @@ if ! $skip_gnulib; then
     snippet/c++defs
     snippet/warn-on-use
     ssize_t
-    stdbool
-    stddef
-    stdint
-    stdlib
+    stddef-h
+    stdint-h
+    stdlib-h
     streq
-    unistd
+    unistd-h
     verify
-    wchar
+    wchar-h
     wctype-h
     windows-mutex
     windows-once
@@ -320,11 +347,16 @@ if ! $skip_gnulib; then
     ansi-c++-opt
     csharpcomp-script
     csharpexec-script
+    d
+    dcomp-script
     java
     javacomp-script
     javaexec-script
     manywarnings
-    stdint
+    modula2
+    modula2comp-script
+    stdint-h
+    test-xfail
   '
   GNULIB_MODULES_TOOLS_LIBUNISTRING_TESTS='
     unilbrk/u8-possible-linebreaks-tests
@@ -336,6 +368,7 @@ if ! $skip_gnulib; then
   GNULIB_MODULES_LIBGETTEXTLIB="$GNULIB_MODULES_TOOLS_FOR_SRC $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES $GNULIB_MODULES_TOOLS_OTHER"
   $GNULIB_TOOL --dir=gettext-tools --lib=libgettextlib --source-base=gnulib-lib --m4-base=gnulib-m4 --tests-base=gnulib-tests --makefile-name=Makefile.gnulib --libtool --with-tests --local-dir=gnulib-local --local-symlink \
     --import \
+    --avoid=hashcode-string1 \
     --avoid=fdutimensat-tests --avoid=futimens-tests --avoid=utime-tests --avoid=utimens-tests --avoid=utimensat-tests \
     --avoid=array-list-tests --avoid=linked-list-tests --avoid=linkedhash-list-tests \
     `for m in $GNULIB_MODULES_TOOLS_LIBUNISTRING_TESTS; do echo --avoid=$m; done` \
@@ -351,7 +384,7 @@ if ! $skip_gnulib; then
     `for m in $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES; do \
        if test \`$GNULIB_TOOL --extract-applicability $m\` != all; then \
          case $m in \
-           locale | stdbool | stddef | stdint | stdlib | unistd | wchar | wctype-h) ;; \
+           bool | locale-h | stddef-h | stdint-h | stdlib-h | unistd-h | wchar-h | wctype-h) ;; \
            *) echo --avoid=$m ;; \
          esac; \
        fi; \
@@ -362,6 +395,7 @@ if ! $skip_gnulib; then
   GNULIB_MODULES_LIBGETTEXTPO='
     attribute
     basename-lgpl
+    bool
     close
     c-ctype
     c-strcase
@@ -385,15 +419,19 @@ if ! $skip_gnulib; then
     open
     relocatable-lib
     sigpipe
-    stdbool
-    stdio
-    stdlib
+    stdio-h
+    stdlib-h
     stpcpy
     stpncpy
+    str_startswith
     strchrnul
     strerror
     string-desc
+    strnlen
     unictype/ctype-space
+    unictype/property-white-space
+    unictype/property-xid-start
+    unictype/property-xid-continue
     unilbrk/ulc-width-linebreaks
     unistr/u8-mbtouc
     unistr/u8-mbtoucr
@@ -463,6 +501,8 @@ if ! $skip_gnulib; then
   $GNULIB_TOOL --copy-file build-aux/update-copyright || exit $?
   $GNULIB_TOOL --copy-file build-aux/useless-if-before-free || exit $?
   $GNULIB_TOOL --copy-file build-aux/vc-list-files || exit $?
+  $GNULIB_TOOL --copy-file m4/init-package-version.m4 || exit $?
+  $GNULIB_TOOL --copy-file m4/version-stamp.m4 || exit $?
   $GNULIB_TOOL --copy-file top/GNUmakefile . || exit $?
   $GNULIB_TOOL --copy-file top/maint.mk . || exit $?
 
