@@ -1,5 +1,5 @@
 /* Boost format strings.
-   Copyright (C) 2001-2004, 2006-2007, 2009, 2019-2020, 2023 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2006.
 
    This program is free software: you can redistribute it and/or modify
@@ -96,12 +96,6 @@ struct spec
   struct numbered_arg *numbered;
 };
 
-/* Locale independent test for a decimal digit.
-   Argument can be  'char' or 'unsigned char'.  (Whereas the argument of
-   <ctype.h> isdigit must be an 'unsigned char'.)  */
-#undef isdigit
-#define isdigit(c) ((unsigned int) ((c) - '0') < 10)
-
 
 static int
 numbered_arg_compare (const void *p1, const void *p2)
@@ -151,7 +145,7 @@ format_parse (const char *format, bool translated, char *fdi,
                 brackets = true;
               }
 
-            if (isdigit (*format) && *format != '0')
+            if (c_isdigit (*format) && *format != '0')
               {
                 const char *f = format;
                 unsigned int m = 0;
@@ -161,7 +155,7 @@ format_parse (const char *format, bool translated, char *fdi,
                     m = 10 * m + (*f - '0');
                     f++;
                   }
-                while (isdigit (*f));
+                while (c_isdigit (*f));
 
                 if ((!brackets && *f == '%') || *f == '$')
                   {
@@ -202,7 +196,7 @@ format_parse (const char *format, bool translated, char *fdi,
 
                     format++;
 
-                    if (isdigit (*format))
+                    if (c_isdigit (*format))
                       {
                         const char *f = format;
                         unsigned int m = 0;
@@ -212,7 +206,7 @@ format_parse (const char *format, bool translated, char *fdi,
                             m = 10 * m + (*f - '0');
                             f++;
                           }
-                        while (isdigit (*f));
+                        while (c_isdigit (*f));
 
                         if (*f == '$')
                           {
@@ -275,9 +269,9 @@ format_parse (const char *format, bool translated, char *fdi,
                         unnumbered_arg_count++;
                       }
                   }
-                else if (isdigit (*format))
+                else if (c_isdigit (*format))
                   {
-                    do format++; while (isdigit (*format));
+                    do format++; while (c_isdigit (*format));
                   }
 
                 /* Parse precision.  */
@@ -291,7 +285,7 @@ format_parse (const char *format, bool translated, char *fdi,
 
                         format++;
 
-                        if (isdigit (*format))
+                        if (c_isdigit (*format))
                           {
                             const char *f = format;
                             unsigned int m = 0;
@@ -301,7 +295,7 @@ format_parse (const char *format, bool translated, char *fdi,
                                 m = 10 * m + (*f - '0');
                                 f++;
                               }
-                            while (isdigit (*f));
+                            while (c_isdigit (*f));
 
                             if (*f == '$')
                               {
@@ -364,9 +358,9 @@ format_parse (const char *format, bool translated, char *fdi,
                             unnumbered_arg_count++;
                           }
                       }
-                    else if (isdigit (*format))
+                    else if (c_isdigit (*format))
                       {
-                        do format++; while (isdigit (*format));
+                        do format++; while (c_isdigit (*format));
                       }
                   }
 
@@ -590,7 +584,7 @@ format_get_number_of_directives (void *descr)
 
 static bool
 format_check (void *msgid_descr, void *msgstr_descr, bool equality,
-              formatstring_error_logger_t error_logger,
+              formatstring_error_logger_t error_logger, void *error_logger_data,
               const char *pretty_msgid, const char *pretty_msgstr)
 {
   struct spec *spec1 = (struct spec *) msgid_descr;
@@ -616,7 +610,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
           if (cmp > 0)
             {
               if (error_logger)
-                error_logger (_("a format specification for argument %u, as in '%s', doesn't exist in '%s'"),
+                error_logger (error_logger_data,
+                              _("a format specification for argument %u, as in '%s', doesn't exist in '%s'"),
                               spec2->numbered[j].number, pretty_msgstr,
                               pretty_msgid);
               err = true;
@@ -627,7 +622,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
               if (equality)
                 {
                   if (error_logger)
-                    error_logger (_("a format specification for argument %u doesn't exist in '%s'"),
+                    error_logger (error_logger_data,
+                                  _("a format specification for argument %u doesn't exist in '%s'"),
                                   spec1->numbered[i].number, pretty_msgstr);
                   err = true;
                   break;
@@ -647,7 +643,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
                 if (spec1->numbered[i].type != spec2->numbered[j].type)
                   {
                     if (error_logger)
-                      error_logger (_("format specifications in '%s' and '%s' for argument %u are not the same"),
+                      error_logger (error_logger_data,
+                                    _("format specifications in '%s' and '%s' for argument %u are not the same"),
                                     pretty_msgid, pretty_msgstr,
                                     spec2->numbered[j].number);
                     err = true;
