@@ -1,5 +1,5 @@
 /* Java printf format strings.
-   Copyright (C) 2001-2004, 2006-2007, 2009-2010, 2018-2020, 2023 Free Software Foundation, Inc.
+   Copyright (C) 2001-2025 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2001.
 
    This program is free software: you can redistribute it and/or modify
@@ -118,12 +118,6 @@ struct spec
   struct numbered_arg *numbered;
 };
 
-/* Locale independent test for a decimal digit.
-   Argument can be  'char' or 'unsigned char'.  (Whereas the argument of
-   <ctype.h> isdigit must be an 'unsigned char'.)  */
-#undef isdigit
-#define isdigit(c) ((unsigned int) ((c) - '0') < 10)
-
 
 static int
 numbered_arg_compare (const void *p1, const void *p2)
@@ -195,7 +189,7 @@ format_parse (const char *format, bool translated, char *fdi,
             number = last_arg_number;
             format++;
           }
-        else if (isdigit (*format))
+        else if (c_isdigit (*format))
           {
             const char *f = format;
             unsigned int m = 0;
@@ -205,7 +199,7 @@ format_parse (const char *format, bool translated, char *fdi,
                 m = 10 * m + (*f - '0');
                 f++;
               }
-            while (isdigit (*f));
+            while (c_isdigit (*f));
 
             if (*f == '$')
               {
@@ -265,9 +259,9 @@ format_parse (const char *format, bool translated, char *fdi,
           }
 
         /* Parse width.  */
-        if (isdigit (*format))
+        if (c_isdigit (*format))
           {
-            do format++; while (isdigit (*format));
+            do format++; while (c_isdigit (*format));
             flags |= FAT_WIDTH;
           }
 
@@ -276,7 +270,7 @@ format_parse (const char *format, bool translated, char *fdi,
           {
             format++;
 
-            if (!isdigit (*format))
+            if (!c_isdigit (*format))
               {
                 if (*format == '\0')
                   {
@@ -291,7 +285,7 @@ format_parse (const char *format, bool translated, char *fdi,
                 goto bad_format;
               }
 
-            do format++; while (isdigit (*format));
+            do format++; while (c_isdigit (*format));
             flags |= FAT_PRECISION;
           }
 
