@@ -1,6 +1,5 @@
 /* Perl format strings.
-   Copyright (C) 2004, 2006-2007, 2009, 2015 Free Software Foundation,
-   Inc.
+   Copyright (C) 2004-2025 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2003.
 
    This program is free software: you can redistribute it and/or modify
@@ -14,7 +13,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -110,18 +109,11 @@ struct spec
 {
   unsigned int directives;
   unsigned int numbered_arg_count;
-  unsigned int allocated;
   struct numbered_arg *numbered;
 };
 
-/* Locale independent test for a decimal digit.
-   Argument can be  'char' or 'unsigned char'.  (Whereas the argument of
-   <ctype.h> isdigit must be an 'unsigned char'.)  */
-#undef isdigit
-#define isdigit(c) ((unsigned int) ((c) - '0') < 10)
-
 /* Locale independent test for a nonzero decimal digit.  */
-#define isnonzerodigit(c) ((unsigned int) ((c) - '1') < 9)
+#define c_isnonzerodigit(c) ((unsigned int) ((c) - '1') < 9)
 
 
 static int
@@ -140,16 +132,16 @@ format_parse (const char *format, bool translated, char *fdi,
   const char *const format_start = format;
   unsigned int directives;
   unsigned int numbered_arg_count;
-  unsigned int allocated;
   struct numbered_arg *numbered;
+  unsigned int numbered_allocated;
   unsigned int unnumbered_arg_count;
   struct spec *result;
 
   directives = 0;
   numbered_arg_count = 0;
-  unnumbered_arg_count = 0;
-  allocated = 0;
   numbered = NULL;
+  numbered_allocated = 0;
+  unnumbered_arg_count = 0;
 
   for (; *format != '\0';)
     if (*format++ == '%')
@@ -163,7 +155,7 @@ format_parse (const char *format, bool translated, char *fdi,
         FDI_SET (format - 1, FMTDIR_START);
         directives++;
 
-        if (isnonzerodigit (*format))
+        if (c_isnonzerodigit (*format))
           {
             const char *f = format;
             unsigned int m = 0;
@@ -173,7 +165,7 @@ format_parse (const char *format, bool translated, char *fdi,
                 m = 10 * m + (*f - '0');
                 f++;
               }
-            while (isdigit (*f));
+            while (c_isdigit (*f));
 
             if (*f == '$')
               {
@@ -204,16 +196,16 @@ format_parse (const char *format, bool translated, char *fdi,
                 vectorize = true;
 
                 /* Unnumbered argument.  */
-                if (allocated == numbered_arg_count)
+                if (numbered_allocated == numbered_arg_count)
                   {
-                    allocated = 2 * allocated + 1;
-                    numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                    numbered_allocated = 2 * numbered_allocated + 1;
+                    numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
                   }
                 numbered[numbered_arg_count].number = ++unnumbered_arg_count;
                 numbered[numbered_arg_count].type = FAT_SCALAR_VECTOR; /* or FAT_STRING? */
                 numbered_arg_count++;
               }
-            else if (isnonzerodigit (*f))
+            else if (c_isnonzerodigit (*f))
               {
                 unsigned int m = 0;
 
@@ -222,7 +214,7 @@ format_parse (const char *format, bool translated, char *fdi,
                     m = 10 * m + (*f - '0');
                     f++;
                   }
-                while (isdigit (*f));
+                while (c_isdigit (*f));
 
                 if (*f == '$')
                   {
@@ -237,10 +229,10 @@ format_parse (const char *format, bool translated, char *fdi,
                         /* Numbered argument.  */
                         /* Note: As of perl-5.8.0, this is not correctly
                            implemented in perl's sv.c.  */
-                        if (allocated == numbered_arg_count)
+                        if (numbered_allocated == numbered_arg_count)
                           {
-                            allocated = 2 * allocated + 1;
-                            numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                            numbered_allocated = 2 * numbered_allocated + 1;
+                            numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
                           }
                         numbered[numbered_arg_count].number = vector_number;
                         numbered[numbered_arg_count].type = FAT_SCALAR_VECTOR; /* or FAT_STRING? */
@@ -253,10 +245,10 @@ format_parse (const char *format, bool translated, char *fdi,
         if (vectorize)
           {
             /* Numbered or unnumbered argument.  */
-            if (allocated == numbered_arg_count)
+            if (numbered_allocated == numbered_arg_count)
               {
-                allocated = 2 * allocated + 1;
-                numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                numbered_allocated = 2 * numbered_allocated + 1;
+                numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
               }
             numbered[numbered_arg_count].number = (number ? number : ++unnumbered_arg_count);
             numbered[numbered_arg_count].type = FAT_SCALAR_VECTOR;
@@ -270,7 +262,7 @@ format_parse (const char *format, bool translated, char *fdi,
 
             format++;
 
-            if (isnonzerodigit (*format))
+            if (c_isnonzerodigit (*format))
               {
                 const char *f = format;
                 unsigned int m = 0;
@@ -280,7 +272,7 @@ format_parse (const char *format, bool translated, char *fdi,
                     m = 10 * m + (*f - '0');
                     f++;
                   }
-                while (isdigit (*f));
+                while (c_isdigit (*f));
 
                 if (*f == '$')
                   {
@@ -292,18 +284,18 @@ format_parse (const char *format, bool translated, char *fdi,
             /* Numbered or unnumbered argument.  */
             /* Note: As of perl-5.8.0, this is not correctly
                implemented in perl's sv.c.  */
-            if (allocated == numbered_arg_count)
+            if (numbered_allocated == numbered_arg_count)
               {
-                allocated = 2 * allocated + 1;
-                numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                numbered_allocated = 2 * numbered_allocated + 1;
+                numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
               }
             numbered[numbered_arg_count].number = (width_number ? width_number : ++unnumbered_arg_count);
             numbered[numbered_arg_count].type = FAT_INTEGER;
             numbered_arg_count++;
           }
-        else if (isnonzerodigit (*format))
+        else if (c_isnonzerodigit (*format))
           {
-            do format++; while (isdigit (*format));
+            do format++; while (c_isdigit (*format));
           }
 
         /* Parse precision.  */
@@ -317,7 +309,7 @@ format_parse (const char *format, bool translated, char *fdi,
 
                 format++;
 
-                if (isnonzerodigit (*format))
+                if (c_isnonzerodigit (*format))
                   {
                     const char *f = format;
                     unsigned int m = 0;
@@ -327,7 +319,7 @@ format_parse (const char *format, bool translated, char *fdi,
                         m = 10 * m + (*f - '0');
                         f++;
                       }
-                    while (isdigit (*f));
+                    while (c_isdigit (*f));
 
                     if (*f == '$')
                       {
@@ -337,10 +329,10 @@ format_parse (const char *format, bool translated, char *fdi,
                   }
 
                 /* Numbered or unnumbered argument.  */
-                if (allocated == numbered_arg_count)
+                if (numbered_allocated == numbered_arg_count)
                   {
-                    allocated = 2 * allocated + 1;
-                    numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                    numbered_allocated = 2 * numbered_allocated + 1;
+                    numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
                   }
                 numbered[numbered_arg_count].number = (precision_number ? precision_number : ++unnumbered_arg_count);
                 numbered[numbered_arg_count].type = FAT_INTEGER;
@@ -348,7 +340,7 @@ format_parse (const char *format, bool translated, char *fdi,
               }
             else
               {
-                while (isdigit (*format)) format++;
+                while (c_isdigit (*format)) format++;
               }
           }
 
@@ -461,10 +453,10 @@ format_parse (const char *format, bool translated, char *fdi,
         if (type != FAT_NONE && !vectorize)
           {
             /* Numbered or unnumbered argument.  */
-            if (allocated == numbered_arg_count)
+            if (numbered_allocated == numbered_arg_count)
               {
-                allocated = 2 * allocated + 1;
-                numbered = (struct numbered_arg *) xrealloc (numbered, allocated * sizeof (struct numbered_arg));
+                numbered_allocated = 2 * numbered_allocated + 1;
+                numbered = (struct numbered_arg *) xrealloc (numbered, numbered_allocated * sizeof (struct numbered_arg));
               }
             numbered[numbered_arg_count].number = (number ? number : ++unnumbered_arg_count);
             numbered[numbered_arg_count].type = type;
@@ -526,7 +518,6 @@ format_parse (const char *format, bool translated, char *fdi,
   result = XMALLOC (struct spec);
   result->directives = directives;
   result->numbered_arg_count = numbered_arg_count;
-  result->allocated = allocated;
   result->numbered = numbered;
   return result;
 
@@ -556,7 +547,7 @@ format_get_number_of_directives (void *descr)
 
 static bool
 format_check (void *msgid_descr, void *msgstr_descr, bool equality,
-              formatstring_error_logger_t error_logger,
+              formatstring_error_logger_t error_logger, void *error_logger_data,
               const char *pretty_msgid, const char *pretty_msgstr)
 {
   struct spec *spec1 = (struct spec *) msgid_descr;
@@ -569,7 +560,7 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
       unsigned int n1 = spec1->numbered_arg_count;
       unsigned int n2 = spec2->numbered_arg_count;
 
-      /* Check the argument names are the same.
+      /* Check that the argument numbers are the same.
          Both arrays are sorted.  We search for the first difference.  */
       for (i = 0, j = 0; i < n1 || j < n2; )
         {
@@ -582,7 +573,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
           if (cmp > 0)
             {
               if (error_logger)
-                error_logger (_("a format specification for argument %u, as in '%s', doesn't exist in '%s'"),
+                error_logger (error_logger_data,
+                              _("a format specification for argument %u, as in '%s', doesn't exist in '%s'"),
                               spec2->numbered[j].number, pretty_msgstr,
                               pretty_msgid);
               err = true;
@@ -593,7 +585,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
               if (equality)
                 {
                   if (error_logger)
-                    error_logger (_("a format specification for argument %u doesn't exist in '%s'"),
+                    error_logger (error_logger_data,
+                                  _("a format specification for argument %u doesn't exist in '%s'"),
                                   spec1->numbered[i].number, pretty_msgstr);
                   err = true;
                   break;
@@ -613,7 +606,8 @@ format_check (void *msgid_descr, void *msgstr_descr, bool equality,
                 if (spec1->numbered[i].type != spec2->numbered[j].type)
                   {
                     if (error_logger)
-                      error_logger (_("format specifications in '%s' and '%s' for argument %u are not the same"),
+                      error_logger (error_logger_data,
+                                    _("format specifications in '%s' and '%s' for argument %u are not the same"),
                                     pretty_msgid, pretty_msgstr,
                                     spec2->numbered[j].number);
                     err = true;
@@ -762,7 +756,7 @@ main ()
 /*
  * For Emacs M-x compile
  * Local Variables:
- * compile-command: "/bin/sh ../libtool --tag=CC --mode=link gcc -o a.out -static -O -g -Wall -I.. -I../gnulib-lib -I../intl -DHAVE_CONFIG_H -DTEST format-perl.c ../gnulib-lib/libgettextlib.la"
+ * compile-command: "/bin/sh ../libtool --tag=CC --mode=link gcc -o a.out -static -O -g -Wall -I.. -I../gnulib-lib -I../../gettext-runtime/intl -DHAVE_CONFIG_H -DTEST format-perl.c ../gnulib-lib/libgettextlib.la"
  * End:
  */
 
